<?php
return [
  'type' => 'primary',
  'entity' => 'User',
  'label' => 'User',
  'defaults' => '{}',
  'icon' => 'fa-user',
  'unique_fields' => ['username'],
];
